@@ -133,17 +133,17 @@ def file_handler(file):
         file = file.replace("'", '"').strip('"')
         if str(file).endswith('.csv'):
             data = pd.read_csv(file)
-            print(Fore.YELLOW + 'AVAILABLE COLUMNS' + Fore.RESET)
+            print(Fore.YELLOW + '\nAVAILABLE COLUMNS' + Fore.RESET)
             for col in data.columns:
                 print(col)
         elif str(file).endswith('.xlsx'):
             data = pd.read_excel(file)
-            print(Fore.YELLOW + 'AVAILABLE COLUMNS' + Fore.RESET)
+            print(Fore.YELLOW + '\nAVAILABLE COLUMNS' + Fore.RESET)
             for col in data.columns:
                 print(col)
         elif str(file).endswith('.json'):
             data = pd.read_json(file)
-            print(Fore.YELLOW + 'AVAILABLE COLUMNS' + Fore.RESET)
+            print(Fore.YELLOW + '\nAVAILABLE COLUMNS' + Fore.RESET)
             for col in data.columns:
                 print(col)
         else:
