@@ -19,15 +19,6 @@ class EOQ:
             order_fixed_cost - integer or float presenting the fixed cost of the order.
             annual_holding_cost - cost of holding the goods in a year.
 
-    (DEVELOPER MODE)
-    ----------------
-
-    Developer mode functions can only be set up manually by removing the '#DEVELOPER MODE -' in the source code.
-
-        * takes no additional arguments.
-        * Requirements:
-            '# DEVELOPER MODE -' removed in the code.
-
     '''
 
     # metadata of the used library.
@@ -42,21 +33,18 @@ class EOQ:
 	__donate__,
 )
 
-    # initial value configuration.
+    # initial launch.
     def __init__(self):
         pass
 
-    # DEVELOPER MODE - @classLog('__str__()')
     # class information.
     def __str__(self):
         return f'EOQ defining object that contains annual demand quantity of {self.annual_demand_quantity} pieces, fixed cost of the order of {self.order_fixed_cost} and with the annual holding cost of {self.annual_holding_cost}.'
 
-    # DEVELOPER MODE - @classLog('__repr__()')
     # class information.
     def __repr__(self):
         return f'EOQ defining object that contains annual demand quantity of {self.annual_demand_quantity} pieces, fixed cost of the order of {self.order_fixed_cost} and with the annual holding cost of {self.annual_holding_cost}.'
 
-    # DEVELOPER MODE - @classLog('execute() - built in function.')
     # executes the calculation of EOQ over the defined parameters.
     def execute(self, annual_demand_quantity, order_fixed_cost, annual_holding_cost):
         self.annual_demand_quantity = annual_demand_quantity
