@@ -5,7 +5,6 @@ colorama.init()
 
 # object that contains the simulation data.
 class MonteCarlo:
-    # coloring the text.
 
     '''
 
@@ -89,7 +88,7 @@ class MonteCarlo:
         self.time_seq = time_seq
         self.num_sims = num_sims
         self.ref_value_index = ref_value_index
-        print(Fore.YELLOW + f'Monte Carlo has been set up for {self.num_sims} simulations in a period of {self.time_seq} time measurement units and executed.' + Fore.RESET)
+        print(Fore.GREEN + f'Monte Carlo has been set up for {self.num_sims} simulations in a period of {self.time_seq} time measurement units and executed.' + Fore.RESET)
         from vandal.hub.toolkit import random_value
         print('NOTE: Use data with reasonable standard deviation in order to prevent exponential growth of the function that cannot be plotted properly, recognize such abnormal values by a + sign anywhere in the data executed below.')
         #print('The model that will be able to handle big standard deviations is currently being worked on, thank you for your patience.\n')
@@ -127,7 +126,7 @@ class MonteCarlo:
 
             data[num_sim] = index_array
         print(end = '\r')
-        print(Fore.YELLOW + 'Monte Carlo simulation set up and ready to plot.' + Fore.RESET)
+        print(Fore.GREEN + 'Monte Carlo simulation set up and ready to plot.' + Fore.RESET)
         self.results = data
         return data
 
@@ -162,14 +161,14 @@ class MonteCarlo:
 
         assert (NRisk < 100), '\nTime sequence and/or number of iterations are too low for the proper risk calculation.'
 
-        print(Fore.YELLOW + '\nRisk for this option is', round(NRisk,2), '%.' + Fore.RESET)
+        print(Fore.GREEN + '\nRisk for this option is' + Fore.RESET, round(NRisk,2), '%.')
 
     # plots the Monte Carlo simulation on a graph.
     def graph(self, graph_title = 'Monte Carlo simulation', x_title = 'X axis', y_title = 'Y axis', plot_size = (25,10), perform_block = True):
         print(Fore.GREEN + '\nMonteCarlo() plotting initialized.' + Fore.RESET)
         import matplotlib.pyplot as plt
         plt.figure(figsize = plot_size)
-        plt.title('vandal (c) David Kundih, 2021.', fontsize = 14, weight = 'regular', loc = 'right')
+        plt.title('vandal (c) David Kundih, 2021-2022', fontsize = 14, weight = 'regular', loc = 'right')
         plt.suptitle(graph_title, fontsize = 25, weight = 'bold')
         plt.plot(self.results)
         plt.axhline(y = self.results[0][0], color = 'k', linestyle = 'solid')
@@ -192,12 +191,12 @@ class MonteCarlo:
         self.standard_deviation = standard_deviation
         self.mean_value = mean_value
         if filtered == False:
-            print('\nNumber of simulations: ', self.time_seq)
-            print('Number of iterations: ', self.num_sims)
-            print('Mean value: ', mean_value)
-            print('Standard deviation: ', standard_deviation)
-            print('Maximum: ', maximum_value)
-            print('Minimum: ', minimum_value)
+            print(Fore.GREEN + '\nNumber of simulations: ' + Fore.RESET, self.time_seq)
+            print(Fore.GREEN + 'Number of iterations: ' + Fore.RESET, self.num_sims)
+            print(Fore.GREEN + 'Mean value: ' + Fore.RESET, mean_value)
+            print(Fore.GREEN + 'Standard deviation: ' + Fore.RESET, standard_deviation)
+            print(Fore.GREEN + 'Maximum: ' + Fore.RESET, maximum_value)
+            print(Fore.GREEN + 'Minimum: ' + Fore.RESET, minimum_value)
 
     # plots the histogram of Monte Carlo simulation.
     def hist(self, graph_title = 'Histogram of value frequencies', x_title = 'X axis', y_title = 'Y axis', plot_size = (25,10), perform_block = True, **method):
@@ -212,10 +211,10 @@ class MonteCarlo:
         if self.time_seq > 50:
             print(Fore.RED + 'NOTE: Time sequence defined greatly impacts the lenght of histogram plotting.\n' + Fore.RESET)
 
-        print(Fore.YELLOW + 'Histogram plotting initiated...' + Fore.RESET)
+        print(Fore.GREEN + 'Histogram plotting initiated...' + Fore.RESET)
         import matplotlib.pyplot as plt
         plt.figure(figsize = plot_size)
-        plt.title('vandal (c) David Kundih, 2021.', fontsize = 14, weight = 'regular', loc = 'right')
+        plt.title('vandal (c) David Kundih, 2021-2022', fontsize = 14, weight = 'regular', loc = 'right')
 
         if method.get("method") != "e":
             print(Fore.GREEN + 'CHOSEN METHOD: Basic histogram model.' + Fore.RESET)
@@ -236,7 +235,7 @@ class MonteCarlo:
         plt.xlabel(x_title, weight = 'semibold')
         plt.ylabel(y_title, weight= 'semibold')
         plt.show(block = perform_block)
-        print(Fore.YELLOW + 'Histogram plotting finished.', Fore.RESET)
+        print(Fore.GREEN + 'Histogram plotting finished.', Fore.RESET)
 
     # access saved menu particles from function execution.  
     def get_menu(self):
@@ -245,6 +244,16 @@ class MonteCarlo:
     
 # CLI application.
 def MCapp():
+
+    '''
+    runs as:
+
+        *IDE: vandal.MCapp()
+        *TERMINAL: python -m vandal -e montecarlo / python -m vandal --entry montecarlo
+        
+    '''
+
+    # relevant imports.
     import os
     from vandal.misc._meta import __version__
     from vandal.objects import MonteCarlo
@@ -255,7 +264,7 @@ def MCapp():
     os.system('cls')
 
     # vandal.App version.
-    __APPversion__ = 'v 1.2.6'
+    __APPversion__ = 'v 1.3.0'
     
     # greeting.
     print(Fore.GREEN + '\n - vandal Command Line Interface Application © David Kundih -', __APPversion__)
@@ -269,7 +278,7 @@ def MCapp():
     if inputchoice == '0':
         import pandas as pd
         iter = True
-        print(Fore.RED + 'Write any non-number value to stop.', Fore.RESET)
+        print(Fore.RED + '\nWrite any non-number value to stop.', Fore.RESET)
         data = []
 
         while iter:
@@ -279,6 +288,7 @@ def MCapp():
                 listinput = float(listinput)
                 data.append(listinput)
             except:
+                print('')
                 iter = False
 
         data = pd.DataFrame(data)
@@ -288,9 +298,12 @@ def MCapp():
     elif inputchoice == '1':
         inputfile = input('Enter the file destination: ')
         data = file_handler(file = inputfile)
+
+    # error on input.
     else:
             raise KeyError('Invalid input, please choose one of the stated options.')
 
+    # simulation parameters and execution.
     MC = MonteCarlo()
     simulations = int(input('Enter number of simulations: ') or 100)
     period = int(input('Enter desired period: ') or 50)
@@ -301,6 +314,7 @@ def MCapp():
     while True:
         action = input('\n>>> ACTIONS: graph, change, values, stats, risk, hist, home, help: ')
         if action == 'graph':
+            print('')
             title = input('Title: ')
             x_axis = input('X axis title:')
             y_axis = input('Y axis title:')
@@ -332,6 +346,7 @@ def MCapp():
             sample = int(input('Number of iterations to measure risk on: ') or 5000)
             MC.get_risk(risk_sims = sample)
         if action == 'hist' or action == 'histogram':
+            print('')
             x_axis = input('X axis title:')
             y_axis = input('Y axis title:')
             print(Fore.YELLOW + '\nHISTOGRAM METHODS', Fore.RESET)
@@ -345,9 +360,11 @@ def MCapp():
             else:
                 print(Fore.RED + '=== INVALID METHOD. ===\n', Fore.RESET)
         if action == 'home':
+            print(Fore.YELLOW + 'Exiting...', Fore.RESET)
             break
         if action == 'help':
             print(Fore.YELLOW + '\nhttps://github.com/dkundih/vandal', Fore.RESET)
 
+# runs module as an app.
 if __name__ == '__main__':
     MCapp()
\ No newline at end of file
